==> 6.3.1.tar.gz: botendo/README.md <==
# Botendo version 6

"6th times the charm" ~ me

A Discord music bot, written in Kotlin using the kord library.
<div class="aside">
    <img src="https://img.shields.io/badge/100%25-Selfmade-success" alt="100% Selfmade"/>
    <img src="https://img.shields.io/badge/0%25-optimized-orange" alt="0% optimized"/>
    <img src="https://img.shields.io/badge/fuck%20it-ship%20it-orange" alt="fuck it, ship it"/>
</div>

## Contributors

<div class="aside">
    <img src="https://img.shields.io/badge/limited__dev-Owner%20%26%20Developer-blue" alt="limited_dev: Owner & Developer"/>
</div>

## Special Thanks to

- HopeBaron for helping me a whole lot

## Known issues

- The Repeat feature does not function
- Not all comments are listed below

## Commands

- info -- Show basic infos about the bot
- play -- Play a song
- stop -- Stop playing a song and leave the vc

## How to self-host (using the Docker container)

1. Pull the container
2. Map /data/ to a folder on disk
3. Run the Bot once
4. Follow step 4 - 7 of "How to self-host (using the JAR)"

## How to self-host (using the JAR)

1. Download the latest release from the Package Registry ("Packages and registries" > "Package Registry")
   1. It should be called something like this: "Botendo-X.X.X-xxxxxxxx-prod.jar" (replace "X.X.X" with the latest
      version and xxxxxxxx" with the commit its based on.)
   2. If you want to run an early version, which may be (very) unsable, you can run a development version. Just use an
      entry ending in "-dev.jar"
2. Place it anywhere you want.
3. Run the following command:
   > java -jar Botendo-X.X.X-xxxxxxxx-prod.jar
4. The bot should start and create a config file named "credentials.nils" in a folder called "data"
5. Open it and put in your credentials.
   1. token: your Discord bot token
   2. lavaip: the IP of your LavaLink instance e.g.: ("ws://192.168.178.1:2333")
   3. lavapw: your password for the LavaLink instance
6. Rerun the command
   > java -jar Botendo-X.X.X-xxxxxxxx-prod.jar
7. The bot should now be up and running.

## How to set up workspace

Install IntellJ and import the project from git.
Done.

## Docker commands 4 me

- docker run -it -m 2g -v/home/limited_dev/Documents/Code/Botendo/run/data/:/data/:rw limiteddev/botendo:x.x.x
- docker build -t limiteddev/botendo:x.x.x .
- docker push limiteddev/botendo:x.x.x

==> 6.3.2.tar.gz: botendo/README.md <==
# Botendo version 6

"6th times the charm" ~ me

A Discord music bot, written in Kotlin using the kord library.
<div class="aside">
    <img src="https://img.shields.io/badge/100%25-Selfmade-success" alt="100% Selfmade"/>
    <img src="https://img.shields.io/badge/0%25-optimized-orange" alt="0% optimized"/>
    <img src="https://img.shields.io/badge/fuck%20it-ship%20it-orange" alt="fuck it, ship it"/>
</div>

## Contributors

<div class="aside">
    <img src="https://img.shields.io/badge/limited__dev-Owner%20%26%20Developer-blue" alt="limited_dev: Owner & Developer"/>
</div>

## Special Thanks to

- HopeBaron for helping me a lot

## Known issues

- The Repeat feature does not function
- The Queue does not show the current song, if there is no song next up
- Not all comments are listed below

## Commands

- info -- Show basic infos about the bot
- play -- Play a song
- stop -- Stop playing a song and leave the vc

## How to self-host (using the Docker container)

1. Pull the container
2. Map /data/ to a folder on disk
3. Run the Bot once
4. Follow step 4 - 7 of "How to self-host (using the JAR)"

## How to self-host (using the JAR)

1. Download the latest release from the Package Registry ("Packages and registries" > "Package Registry")
   1. It should be called something like this: "Botendo-X.X.X-xxxxxxxx-prod.jar" (replace "X.X.X" with the latest
      version and xxxxxxxx" with the commit its based on.)
   2. If you want to run an early version, which may be (very) unsable, you can run a development version. Just use an
      entry ending in "-dev.jar"
2. Place it anywhere you want.
3. Run the following command:
   > java -jar Botendo-X.X.X-xxxxxxxx-prod.jar
4. The bot should start and create a config file named "credentials.nils" in a folder called "data"
5. Open it and put in your credentials.
   1. token: your Discord bot token
   2. lavaip: the IP of your LavaLink instance e.g.: ("ws://192.168.178.1:2333")
   3. lavapw: your password for the LavaLink instance
6. Rerun the command
   > java -jar Botendo-X.X.X-xxxxxxxx-prod.jar
7. The bot should now be up and running.

## How to set up workspace

Install IntellJ and import the project from git.
Done.

## Docker commands 4 me

- docker run -it -m 2g -v/home/limited_dev/Documents/Code/Botendo/run/data/:/data/:rw limiteddev/botendo:x.x.x
- docker build -t limiteddev/botendo:x.x.x .
- docker push limiteddev/botendo:x.x.x
